Module console

Module console 

Legacy console entry point.

New code should use Launcher instead, which provides the same REPL with additional configuration options (memory, artifacts, streaming mode, etc.).

Functions

run_console
Run an interactive console session with the given agent.