Module serve

Module serve 

Legacy serve entry point.

New code should use Launcher instead, which provides the same server with additional configuration options (security, memory, artifacts, graceful shutdown, etc.).

Functions

run_serve
Start a web server with the given agent loader.