Simple launcher for ADK agents with CLI support.
Provides a one-liner to run agents with console or web server modes, similar to adk-go’s launcher pattern.
Example
ⓘ
use adk_cli::Launcher;
use std::sync::Arc;
#[tokio::main]
async fn main() -> adk_core::Result<()> {
let agent = /* create your agent */;
// Run with CLI support (console by default, or `serve` for web)
Launcher::new(Arc::new(agent)).run().await
}CLI Usage
# Interactive console (default)
cargo run
# Web server with UI
cargo run -- serve
cargo run -- serve --port 3000Structs
- Launcher
- Launcher for running ADK agents with CLI support.
- Stream
Printer - Handles streaming output with special rendering for think blocks, tool calls, function responses, and inline/file data.
Enums
- Telemetry
Config - Controls how serve mode initializes telemetry.
- Thinking
Display Mode - Controls how the console renders thinking/reasoning content.